==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgprofilesettings.h <==
/***************************************************************************
                          dlgprofilesettings.h  -  profile settings
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : P oct 18 2002
    copyright            : (C) 2002-2004 by Tomas Mecir
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGPROFILESETTINGS_H
#define DLGPROFILESETTINGS_H

#include <config.h>

#include <qwidget.h>
#include <kdialogbase.h>

class QCheckBox;
class QComboBox;
class KLineEdit;
class cDirList;

/**
Dialog that allows changing of profile-related settings.
  *@author Tomas Mecir
  */

class dlgProfileSettings : public KDialogBase  {
   Q_OBJECT
public: 
  dlgProfileSettings (QWidget *parent=0, const char *name=0);
  ~dlgProfileSettings ();

  bool useAnsi ();
  void setUseAnsi (bool val);
  bool limitTriggers ();
  void setLimitTriggers (bool val);
  bool limitRepeater ();
  void setLimitRepeater (bool val);
  bool negotiateOnStartup ();
  void setNegotiateOnStartup (bool val);
  bool promptLabel();
  void setPromptLabel (bool val);
  bool LPMudStyle();
  void setLPMudStyle (bool val);
  QString movementCmd (int which);
  bool statusPrompt();
  void setStatusPrompt(bool val);
  bool consolePrompt();
  void setConsolePrompt(bool val);
  bool autoAdvTranscript();
  void setAutoAdvTranscript(bool val);
  
  void setMovementCmd (int which, QString val);
  QString quitCmd ();
  void setQuitCmd (QString val);
  QString scriptDir ();
  void setScriptDir (const QString &s);
  QString scriptWorkDir ();
  void setScriptWorkDir (const QString &s);
  QString transcriptDir ();
  void setTranscriptDir (const QString &s);
#ifdef HAVE_SOUND
  bool useMSP ();
  void setUseMSP (bool val);
  bool alwaysMSP ();
  void setAlwaysMSP (bool val);
  bool midlineMSP ();
  void setMidlineMSP (bool val);
  const QStringList &soundDirList ();
  void setSoundDirList (const QStringList &list);
#endif
#ifdef HAVE_MXP
  int MXPAllowed ();
  void setMXPAllowed (int allow);
  void setVariablePrefix (const QString &prefix);
  QString variablePrefix ();
#endif
protected slots:
  void choosedir1 ();
  void choosedir2 ();
  void choosedir3 ();
protected:
  QCheckBox *useansi, *limittriggers, *limitrepeater, *startupneg, *promptlabel;
  QCheckBox *lpmudstyle, *statusprompt, *consoleprompt;
  QCheckBox *autoadvtranscript;
  KLineEdit *edcmd[10];
  KLineEdit *edquit;
  KLineEdit *edscriptdir, *edscriptworkdir;
  KLineEdit *edtranscriptdir;
#ifdef HAVE_SOUND
  QCheckBox *usemsp;
  cDirList *dirlist;
  QCheckBox *alwaysmsp, *midlinemsp;
#endif
#ifdef HAVE_MXP
  QComboBox *cbmxpallowed;
  KLineEdit *edvarprefix;
#endif
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgprofilesettings.h <==
/***************************************************************************
                          dlgprofilesettings.h  -  profile settings
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : P oct 18 2002
    copyright            : (C) 2002-2004 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGPROFILESETTINGS_H
#define DLGPROFILESETTINGS_H

#include <config.h>

#include <qwidget.h>
#include <kdialogbase.h>

class QCheckBox;
class QComboBox;
class KLineEdit;
class cDirList;

/**
Dialog that allows changing of profile-related settings.
  *@author Tomas Mecir
  */

class dlgProfileSettings : public KDialogBase  {
   Q_OBJECT
public: 
  dlgProfileSettings (QWidget *parent=0, const char *name=0);
  ~dlgProfileSettings ();

  bool useAnsi ();
  void setUseAnsi (bool val);
  bool limitTriggers ();
  void setLimitTriggers (bool val);
  bool limitRepeater ();
  void setLimitRepeater (bool val);
  bool negotiateOnStartup ();
  void setNegotiateOnStartup (bool val);
  bool promptLabel();
  void setPromptLabel (bool val);
  bool LPMudStyle();
  void setLPMudStyle (bool val);
  QString movementCmd (int which);
  bool statusPrompt();
  void setStatusPrompt(bool val);
  bool consolePrompt();
  void setConsolePrompt(bool val);
  bool autoAdvTranscript();
  void setAutoAdvTranscript(bool val);
  
  void setMovementCmd (int which, QString val);
  QString quitCmd ();
  void setQuitCmd (QString val);
  QString scriptDir ();
  void setScriptDir (const QString &s);
  QString scriptWorkDir ();
  void setScriptWorkDir (const QString &s);
  QString transcriptDir ();
  void setTranscriptDir (const QString &s);
#ifdef HAVE_SOUND
  bool useMSP ();
  void setUseMSP (bool val);
  bool alwaysMSP ();
  void setAlwaysMSP (bool val);
  bool midlineMSP ();
  void setMidlineMSP (bool val);
  const QStringList &soundDirList ();
  void setSoundDirList (const QStringList &list);
#endif
#ifdef HAVE_MXP
  int MXPAllowed ();
  void setMXPAllowed (int allow);
  void setVariablePrefix (const QString &prefix);
  QString variablePrefix ();
#endif
protected slots:
  void choosedir1 ();
  void choosedir2 ();
  void choosedir3 ();
protected:
  QCheckBox *useansi, *limittriggers, *limitrepeater, *startupneg, *promptlabel;
  QCheckBox *lpmudstyle, *statusprompt, *consoleprompt;
  QCheckBox *autoadvtranscript;
  KLineEdit *edcmd[10];
  KLineEdit *edquit;
  KLineEdit *edscriptdir, *edscriptworkdir;
  KLineEdit *edtranscriptdir;
#ifdef HAVE_SOUND
  QCheckBox *usemsp;
  cDirList *dirlist;
  QCheckBox *alwaysmsp, *midlinemsp;
#endif
#ifdef HAVE_MXP
  QComboBox *cbmxpallowed;
  KLineEdit *edvarprefix;
#endif
};

#endif
